# peeringdb-py

[![PyPI](https://img.shields.io/pypi/v/peeringdb.svg?maxAge=3600)](https://pypi.python.org/pypi/peeringdb)
[![Travis CI](https://img.shields.io/travis/peeringdb/peeringdb-py.svg?maxAge=3600)](https://travis-ci.org/peeringdb/peeringdb-py)
[![Code Health](https://landscape.io/github/peeringdb/peeringdb-py/master/landscape.svg?style=flat)](https://landscape.io/github/peeringdb/peeringdb-py/master)
[![Codecov](https://img.shields.io/codecov/c/github/peeringdb/peeringdb-py/master.svg?maxAge=3600)](https://codecov.io/github/peeringdb/peeringdb-py)
[![Requires.io](https://img.shields.io/requires/github/peeringdb/peeringdb-py.svg?maxAge=3600)](https://requires.io/github/peeringdb/peeringdb-py/requirements)

PeeringDB python client

See http://peeringdb.github.io/peeringdb-py/ for docs
